@@ -1,29 +1,15 @@
 /*
-    Copyright (c) 2009 Volker Krause <vkrause@kde.org>
-    Copyright (c) 2010 Tom Albers <toma@kde.org>
-    Copyright (C) 2012-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2009 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2010 Tom Albers <toma@kde.org>
+    SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "personaldatapage.h"
 
 #include <config-enterprise.h>
 #include "global.h"
-#include "dialog.h"
 #include "transport.h"
 #include "resource.h"
 #include "ispdb/ispdb.h"
@@ -52,7 +38,7 @@ PersonalDataPage::PersonalDataPage(Dialog *parent)
     ui.setupUi(pageParent);
     ui.mProgress->stop();
 
-    PimCommon::EmailValidator *emailValidator = new PimCommon::EmailValidator(this);
+    auto *emailValidator = new PimCommon::EmailValidator(this);
     ui.emailEdit->setValidator(emailValidator);
 
     // KEmailSettings defaults
@@ -172,7 +158,7 @@ void PersonalDataPage::configureSmtpAccount()
         qCDebug(ACCOUNTWIZARD_LOG) << "Configuring transport for" << s.hostname;
 
         QObject *object = mSetupManager->createTransport(QStringLiteral("smtp"));
-        Transport *t = qobject_cast<Transport *>(object);
+        auto *t = qobject_cast<Transport *>(object);
         t->setName(accountName(mIspdb, s.username));
         t->setHost(s.hostname);
         t->setPort(s.port);
@@ -223,7 +209,7 @@ void PersonalDataPage::configureImapAccount()
         qCDebug(ACCOUNTWIZARD_LOG) << "Configuring imap for" << s.hostname;
 
         QObject *object = mSetupManager->createResource(QStringLiteral("akonadi_imap_resource"));
-        Resource *t = qobject_cast<Resource *>(object);
+        auto *t = qobject_cast<Resource *>(object);
         t->setName(accountName(mIspdb, s.username));
         t->setOption(QStringLiteral("ImapServer"), s.hostname);
         t->setOption(QStringLiteral("ImapPort"), s.port);
@@ -275,7 +261,7 @@ void PersonalDataPage::configurePop3Account()
         qCDebug(ACCOUNTWIZARD_LOG) << "No Imap to be created, configuring pop3 for" << s.hostname;
 
         QObject *object = mSetupManager->createResource(QStringLiteral("akonadi_pop3_resource"));
-        Resource *t = qobject_cast<Resource *>(object);
+        auto *t = qobject_cast<Resource *>(object);
         t->setName(accountName(mIspdb, s.username));
         t->setOption(QStringLiteral("Host"), s.hostname);
         t->setOption(QStringLiteral("Port"), s.port);
